@@ -13,6 +13,8 @@ from ....mesh import Mesh
 from ....lib import yellow, red, toiter, first
 from .... import exceptions
 
+import fastremap
+
 def extract_lod_meshes(manifest, lod, lod_binary, vertex_quantization_bits, transform):
   meshdata = defaultdict(list)
   for frag in range(manifest.fragment_offsets[lod].shape[0]):
@@ -241,10 +243,12 @@ class ShardedMultiLevelPrecomputedMeshSource(UnshardedLegacyPrecomputedMeshSourc
       ]
       total_fragment_size = np.sum(fragment_sizes)
       full_path = self.reader.meta.join(self.reader.meta.cloudpath)
+
+      manifest_byte_start = (manifest.shard_offset - total_fragment_size) + np.sum(fragment_sizes[0:lod])
       lod_binary = CloudFiles(full_path, progress=progress, secrets=self.config.secrets).get({
         'path': manifest.path,
-        'start': (manifest.shard_offset - total_fragment_size) + np.sum(fragment_sizes[0:lod]),
-        'end': (manifest.shard_offset - total_fragment_size) + np.sum(fragment_sizes[0:lod+1]),  
+        'start': int(manifest_byte_start),
+        'end': int(manifest_byte_start + fragment_sizes[lod]),
       })
 
       meshes = extract_lod_meshes(
@@ -412,7 +416,7 @@ def from_stored_model_space(
   chunk_shape[j] * (2**lod) * (fragmentPosition[j] +
                                x / ((2**vertex_quantization_bits)-1))
   """
-  return (
+  return np.array(
     manifest.grid_origin + 
     manifest.vertex_offsets[lod] + (
       manifest.chunk_shape * (2 ** lod) * (
@@ -430,7 +434,7 @@ def to_stored_model_space(
   frag:int
 ) -> np.ndarray:
   """Inverse of from_stored_model_space (see explaination there)."""
-  vertices = vertices.astype(np.float64)
+  vertices = vertices.astype(np.float32, copy=False)
   quant_factor = ((2 ** vertex_quantization_bits) - 1) 
 
   stored_model = vertices - manifest.grid_origin - manifest.vertex_offsets[lod]
@@ -438,7 +442,14 @@ def to_stored_model_space(
   stored_model -= manifest.fragment_positions[lod][:,frag]
   stored_model *= quant_factor
   stored_model = np.round(stored_model, out=stored_model)
-  return np.clip(
+  stored_model = np.clip(
     stored_model, 0, quant_factor, 
     out=stored_model
-  )
\ No newline at end of file
+  )
+
+  dtype = fastremap.fit_dtype(np.uint64, value=quant_factor)
+  return stored_model.astype(dtype)
+
+
+
+
